package com.fs.wxUser.service;

import com.fs.wxUser.domain.CompanyWxUserGroup;

import java.util.List;

/**
 * 个微 分组Service接口
 * 
 * @author fs
 * @date 2024-10-25
 */
public interface ICompanyWxUserGroupService 
{
    /**
     * 查询个微 分组
     * 
     * @param groupId 个微 分组主键
     * @return 个微 分组
     */
    public CompanyWxUserGroup selectCompanyWxUserGroupByGroupId(Long groupId);

    /**
     * 查询个微 分组列表
     * 
     * @param companyWxUserGroup 个微 分组
     * @return 个微 分组集合
     */
    public List<CompanyWxUserGroup> selectCompanyWxUserGroupList(CompanyWxUserGroup companyWxUserGroup);

    /**
     * 新增个微 分组
     * 
     * @param companyWxUserGroup 个微 分组
     * @return 结果
     */
    public int insertCompanyWxUserGroup(CompanyWxUserGroup companyWxUserGroup);

    /**
     * 修改个微 分组
     * 
     * @param companyWxUserGroup 个微 分组
     * @return 结果
     */
    public int updateCompanyWxUserGroup(CompanyWxUserGroup companyWxUserGroup);

    /**
     * 批量删除个微 分组
     * 
     * @param groupIds 需要删除的个微 分组主键集合
     * @return 结果
     */
    public int deleteCompanyWxUserGroupByGroupIds(Long[] groupIds);

    /**
     * 删除个微 分组信息
     * 
     * @param groupId 个微 分组主键
     * @return 结果
     */
    public int deleteCompanyWxUserGroupByGroupId(Long groupId);
}
